@@ -24,7 +24,7 @@ function(X, r = NULL, NumberOfSimulations = 100, Alpha = 0.05,
                                         PopulationIndependence = "Population Independence"
                                         )
   # Calculate confidence intervals
-  Envelope <- FillEnveloppe(Envelope, Alpha, Global)
+  Envelope <- FillEnvelope(Envelope, Alpha, Global)
   # Return the envelope
   return (Envelope)
 }
